/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.fulltext.analyzer.providers;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.analysis.util.CharArraySet;

import org.neo4j.graphdb.index.fulltext.AnalyzerProvider;
import org.neo4j.helpers.Service;

@Service.Implementation( AnalyzerProvider.class )
public class StandardNoStopWords extends AnalyzerProvider
{
    public static final String ANALYZER_NAME = "standard-no-stop-words";

    public StandardNoStopWords()
    {
        super( ANALYZER_NAME );
    }

    @Override
    public Analyzer createAnalyzer()
    {
        return new StandardAnalyzer( CharArraySet.EMPTY_SET );
    }

    @Override
    public String description()
    {
        return "Similar to the 'standard' analyzer, but filters no stop words. " +
                "Tokenizes on non-letter boundaries and filters out punctuation. " +
                "Does no stemming, but takes care to keep likely product names, URLs and email addresses as single terms.";
    }
}
