/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.transaction.log.entry;

import java.io.IOException;

import org.neo4j.helpers.collection.Visitor;
import org.neo4j.storageengine.api.StorageCommand;
import org.neo4j.storageengine.api.WritableChannel;

import static org.neo4j.kernel.impl.transaction.log.entry.LogEntryByteCodes.COMMAND;

public class StorageCommandSerializer implements Visitor<StorageCommand,IOException>
{
    private final WritableChannel channel;

    public StorageCommandSerializer( WritableChannel channel )
    {
        this.channel = channel;
    }

    @Override
    public boolean visit( StorageCommand command ) throws IOException
    {
        LogEntryWriter.writeLogEntryHeader( COMMAND, channel );
        command.serialize( channel );
        return false;
    }
}
